# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class MonitorFormulaAndFunctionEventQueryDefinitionSearch(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "query": (str,),
        }

    attribute_map = {
        "query": "query",
    }

    def __init__(self, query, *args, **kwargs):
        """
        Search options.

        :param query: Events search string.
        :type query: str
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.query = query

    @classmethod
    def _from_openapi_data(cls, query, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(MonitorFormulaAndFunctionEventQueryDefinitionSearch, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.query = query
        return self
